@@ -1,5 +1,5 @@
 #ifndef _CONFIG_H
-#error "config_bottom.h should only be included from config.h"
+# error "config_bottom.h should only be included from config.h"
 #endif /* _CONFIG_H */
 
 #include "util/util.h"
@@ -29,6 +29,11 @@
 # define strdup vt_strdup
 #endif /* HAVE_STRDUP */
 
+#if !(defined(HAVE_MEMMOVE) && HAVE_MEMMOVE)
+# undef memmove
+# define memmove vt_memmove
+#endif /* HAVE_MEMMOVE */
+
 #if defined(HAVE_FNMATCH_H) && HAVE_FNMATCH_H
 # include <fnmatch.h>
 #else /* HAVE_FNMATCH_H */
@@ -38,10 +43,22 @@
 # define vt_fnmatch(_pattern, _string, __flags) strcmp(_string, _pattern)
 #endif /* HAVE_FNMATCH_H */
 
-#include <limits.h>
 #if defined(HAVE_SYS_PARAM_H) && HAVE_SYS_PARAM_H
 # include <sys/param.h>
 #endif
+
+#if defined(MIN)
+# define VT_MIN MIN
+#else
+# define VT_MIN(a,b) (((a)<(b))?(a):(b))
+#endif
+#if defined(MAX)
+# define VT_MAX MAX
+#else
+# define VT_MAX(a,b) (((a)>(b))?(a):(b))
+#endif
+
+#include <limits.h>
 #if defined(PATH_MAX)
 # define VT_PATH_MAX (PATH_MAX + 1)
 #elif defined(_POSIX_PATH_MAX)
