@@ -1,9 +1,9 @@
 /*
- This is part of the OTF library. Copyright by ZIH, TU Dresden 2005-2011.
+ This is part of the OTF library. Copyright by ZIH, TU Dresden 2005-2012.
  Authors: Andreas Knuepfer, Holger Brunst, Ronny Brendel, Thomas Kriebitzsch
 */
 
-/** 
+/**
  *  @file OTF_HandlerArray.h
  *
  *  @brief Provides read access to OTF traces which consist of multiple
@@ -25,11 +25,11 @@
  * global definition which is the default.
  */
 
-/** 
+/**
  * \defgroup ha Handler Array Interface
  *
  * Using this interface you can setup a handler array for reading traces.
- * 
+ *
  */
 
 #ifndef OTF_HANDLERARRAY_H
@@ -70,20 +70,20 @@ int OTF_HandlerArray_close( OTF_HandlerArray* handlers );
 
 /** Assign the function pointer to your own handler of the given record
     type. \ingroup ha */
-int OTF_HandlerArray_setHandler( OTF_HandlerArray* handlers, 
+int OTF_HandlerArray_setHandler( OTF_HandlerArray* handlers,
         OTF_FunctionPointer* pointer, uint32_t recordtype );
 
 /** Assign the first argument to your own handler of the given record type.
 \ingroup ha */
-int OTF_HandlerArray_setFirstHandlerArg( OTF_HandlerArray* handlers, 
+int OTF_HandlerArray_setFirstHandlerArg( OTF_HandlerArray* handlers,
         void* firsthandlerarg, uint32_t recordtype );
 
 /** Provide copy handlers to every record type. \ingroup ha */
-int OTF_HandlerArray_getCopyHandler( OTF_HandlerArray* handlers, 
+int OTF_HandlerArray_getCopyHandler( OTF_HandlerArray* handlers,
         OTF_Writer* writer );
 
 /** Provide copy handlers to every record type for OTF streams. \ingroup ha */
-int OTF_HandlerArray_getCopyHandler_stream( OTF_HandlerArray* handlers, 
+int OTF_HandlerArray_getCopyHandler_stream( OTF_HandlerArray* handlers,
         OTF_WStream* writer );
 
 
@@ -95,16 +95,16 @@ int OTF_HandlerArray_getCopyHandler_stream( OTF_HandlerArray* handlers,
 
 /* - the following part is also used to create the python wrapper automatically
    - respect these rules to avoid problems while generating:
-	- write the definition macro as a comment (with a '#' placed in front)
-	  one line above the typedef itself
-	- the use of the following datatypes is possible: char, uint8_t, uint32_t, uint64_t
-	- the first parameter must be a "void*" pointer
-	- to use pointer as parameter is very critical and requires some additional rules:
-		- pointer of type "char*" are allowed anytime
-		- pointer of type "uint32_t*" are allowed but the previous parameter must
-		  be of type "uint32_t" and contain the number of elements that are in the array
-		  the pointer references to
-		- pointer of type "void*" are allowed as the first parameter only
+        - write the definition macro as a comment (with a '#' placed in front)
+          one line above the typedef itself
+        - the use of the following datatypes is possible: char, uint8_t, uint32_t, uint64_t
+        - the first parameter must be a "void*" pointer
+        - to use pointer as parameter is very critical and requires some additional rules:
+                - pointer of type "char*" are allowed anytime
+                - pointer of type "uint32_t*" are allowed but the previous parameter must
+                  be of type "uint32_t" and contain the number of elements that are in the array
+                  the pointer references to
+                - pointer of type "void*" are allowed as the first parameter only
 
     - if you have to add a record that breaks one of the above-mentioned rules the generation
       will skip this record and you manually have to update the python wrapper ( see
@@ -118,15 +118,15 @@ int OTF_HandlerArray_getCopyHandler_stream( OTF_HandlerArray* handlers,
 
 /* # OTF_DEFINITIONCOMMENT_RECORD */
 typedef int (OTF_Handler_DefinitionComment) ( void* userData,
-					                          uint32_t stream,
-					                          const char* comment,
-				  	                          OTF_KeyValueList *list );
+                                              uint32_t stream,
+                                              const char* comment,
+                                              OTF_KeyValueList *list );
 
-/* # OTF_DEFTIMERRESOLUTION_RECORD */				  	      
+/* # OTF_DEFTIMERRESOLUTION_RECORD */
 typedef int (OTF_Handler_DefTimerResolution) ( void* userData,
                                                uint32_t stream,
                                                uint64_t ticksPerSecond,
-				  	                           OTF_KeyValueList *list );
+                                               OTF_KeyValueList *list );
 
 /* # OTF_DEFPROCESS_RECORD */
 typedef int (OTF_Handler_DefProcess) ( void* userData,
@@ -134,7 +134,7 @@ typedef int (OTF_Handler_DefProcess) ( void* userData,
                                        uint32_t process,
                                        const char* name,
                                        uint32_t parent,
-				                       OTF_KeyValueList *list );
+                                       OTF_KeyValueList *list );
 
 /* # OTF_DEFPROCESSGROUP_RECORD */
 typedef int (OTF_Handler_DefProcessGroup) ( void* userData,
@@ -143,22 +143,22 @@ typedef int (OTF_Handler_DefProcessGroup) ( void* userData,
                                             const char* name,
                                             uint32_t numberOfProcs,
                                             const uint32_t* procs,
-				  	                        OTF_KeyValueList *list );
+                                            OTF_KeyValueList *list );
 
 /* # OTF_DEFATTRLIST_RECORD */
 typedef int (OTF_Handler_DefAttributeList) ( void* userData,
-					                         uint32_t stream,
-					                         uint32_t attr_token,
-					                         uint32_t num,
-					                         OTF_ATTR_TYPE* array,
+                                             uint32_t stream,
+                                             uint32_t attr_token,
+                                             uint32_t num,
+                                             OTF_ATTR_TYPE* array,
                                              OTF_KeyValueList *list );
 
 /* # OTF_DEFPROCESSORGROUPATTR_RECORD */
 typedef int (OTF_Handler_DefProcessOrGroupAttributes) ( void* userData,
-						                                uint32_t stream,
-						                                uint32_t proc_token,
-						                                uint32_t attr_token,
-				  	    		                        OTF_KeyValueList *list ); 
+                                                        uint32_t stream,
+                                                        uint32_t proc_token,
+                                                        uint32_t attr_token,
+                                                        OTF_KeyValueList *list );
 
 /* # OTF_DEFFUNCTION_RECORD */
 typedef int (OTF_Handler_DefFunction) ( void* userData,
@@ -167,14 +167,14 @@ typedef int (OTF_Handler_DefFunction) ( void* userData,
                                         const char* name,
                                         uint32_t funcGroup,
                                         uint32_t source,
-				  	                    OTF_KeyValueList *list );
+                                        OTF_KeyValueList *list );
 
 /* # OTF_DEFFUNCTIONGROUP_RECORD */
 typedef int (OTF_Handler_DefFunctionGroup) ( void* userData,
                                              uint32_t stream,
                                              uint32_t funcGroup,
                                              const char* name,
-				  	                        OTF_KeyValueList *list );
+                                             OTF_KeyValueList *list );
 
 /* # OTF_DEFCOLLOP_RECORD */
 typedef int (OTF_Handler_DefCollectiveOperation) ( void* userData,
@@ -182,7 +182,7 @@ typedef int (OTF_Handler_DefCollectiveOperation) ( void* userData,
                                                    uint32_t collOp,
                                                    const char* name,
                                                    uint32_t type,
-				  		                           OTF_KeyValueList *list );
+                                                   OTF_KeyValueList *list );
 
 /* # OTF_DEFCOUNTER_RECORD */
 typedef int (OTF_Handler_DefCounter) ( void* userData,
@@ -192,14 +192,14 @@ typedef int (OTF_Handler_DefCounter) ( void* userData,
                                        uint32_t properties,
                                        uint32_t counterGroup,
                                        const char* unit,
-				                       OTF_KeyValueList *list );
+                                       OTF_KeyValueList *list );
 
 /* # OTF_DEFCOUNTERGROUP_RECORD */
 typedef int (OTF_Handler_DefCounterGroup) ( void* userData,
                                             uint32_t stream,
                                             uint32_t counterGroup,
                                             const char* name,
-				  	                        OTF_KeyValueList *list );
+                                            OTF_KeyValueList *list );
 
 /* # OTF_DEFSCL_RECORD */
 typedef int (OTF_Handler_DefScl) ( void* userData,
@@ -207,14 +207,14 @@ typedef int (OTF_Handler_DefScl) ( void* userData,
                                    uint32_t source,
                                    uint32_t sourceFile,
                                    uint32_t line,
-				                   OTF_KeyValueList *list );
+                                   OTF_KeyValueList *list );
 
 /* # OTF_DEFSCLFILE_RECORD */
 typedef int (OTF_Handler_DefSclFile) ( void* userData,
                                        uint32_t stream,
                                        uint32_t sourceFile,
                                        const char* name,
-				                       OTF_KeyValueList *list );
+                                       OTF_KeyValueList *list );
 
 /* # OTF_DEFCREATOR_RECORD */
 typedef int (OTF_Handler_DefCreator) ( void* userData,
@@ -222,6 +222,12 @@ typedef int (OTF_Handler_DefCreator) ( void* userData,
                                        const char* creator,
                                        OTF_KeyValueList *list );
 
+/* # OTF_DEFUNIQUEID_RECORD */
+typedef int (OTF_Handler_DefUniqueId) ( void* userData,
+                                        uint32_t stream,
+                                        uint64_t uid,
+                                        OTF_KeyValueList *list );
+
 /* # OTF_DEFVERSION_RECORD */
 typedef int (OTF_Handler_DefVersion) ( void* userData,
                                        uint32_t stream,
@@ -237,47 +243,54 @@ typedef int (OTF_Handler_DefFile) ( void* userData,
                                     uint32_t token,
                                     const char *name,
                                     uint32_t group,
-				                    OTF_KeyValueList *list );
+                                    OTF_KeyValueList *list );
 
 /* # OTF_DEFFILEGROUP_RECORD */
 typedef int (OTF_Handler_DefFileGroup) ( void* userData,
                                          uint32_t stream,
                                          uint32_t token,
                                          const char *name,
-				  	                     OTF_KeyValueList *list );
+                                         OTF_KeyValueList *list );
 
 /* # OTF_DEFKEYVALUE_RECORD */
 typedef int (OTF_Handler_DefKeyValue) (  void* userData,
                                          uint32_t stream,
                                          uint32_t key,
-					                     OTF_Type type,
+                                         OTF_Type type,
                                          const char *name,
-					                     const char *description,
-				  	                     OTF_KeyValueList *list );
+                                         const char *description,
+                                         OTF_KeyValueList *list );
 
 /* # OTF_DEFTIMERANGE_RECORD */
-typedef int (OTF_Handler_DefTimeRange) ( void*             userData,
-                                         uint32_t          stream,
-                                         uint64_t          minTime,
-                                         uint64_t          maxTime,
+typedef int (OTF_Handler_DefTimeRange) ( void* userData,
+                                         uint32_t stream,
+                                         uint64_t minTime,
+                                         uint64_t maxTime,
                                          OTF_KeyValueList* list );
 
 /* # OTF_DEFCOUNTERASSIGNMENTS_RECORD */
-typedef int (OTF_Handler_DefCounterAssignments) ( void*             userData,
-                                                  uint32_t          stream,
-                                                  uint32_t          counter,
-                                                  uint32_t          number_of_members,
-                                                  const uint32_t*   procs_or_groups,
+typedef int (OTF_Handler_DefCounterAssignments) ( void* userData,
+                                                  uint32_t stream,
+                                                  uint32_t counter,
+                                                  uint32_t number_of_members,
+                                                  const uint32_t* procs_or_groups,
                                                   OTF_KeyValueList* list );
 
 /* # OTF_DEFPROCESSSUBSTITUTES_RECORD */
-typedef int (OTF_Handler_DefProcessSubstitutes) ( void*             userData,
-                                                  uint32_t          stream,
-                                                  uint32_t          representative,
-                                                  uint32_t          numberOfProcs,
-                                                  const uint32_t*   procs,
+typedef int (OTF_Handler_DefProcessSubstitutes) ( void* userData,
+                                                  uint32_t stream,
+                                                  uint32_t representative,
+                                                  uint32_t numberOfProcs,
+                                                  const uint32_t* procs,
                                                   OTF_KeyValueList* list );
 
+/* # OTF_DEFAUXSAMPLEPOINT_RECORD */
+typedef int (OTF_Handler_DefAuxSamplePoint) ( void* userData,
+                                              uint32_t stream,
+                                              uint64_t time,
+                                              OTF_AuxSamplePointType type,
+                                              OTF_KeyValueList* list );
+
 /* typedefs for OTF event records ****************************************** */
 
 /* # OTF_NOOP_RECORD */
@@ -286,13 +299,13 @@ typedef int (OTF_Handler_NoOp) ( void* userData,
                                  uint32_t process,
                                  OTF_KeyValueList *list );
 
-/* # OTF_ENTER_RECORD */                             
+/* # OTF_ENTER_RECORD */
 typedef int (OTF_Handler_Enter) ( void* userData,
                                   uint64_t time,
                                   uint32_t function,
                                   uint32_t process,
                                   uint32_t source,
-				                  OTF_KeyValueList *list );
+                                  OTF_KeyValueList *list );
 
 /* # OTF_LEAVE_RECORD */
 typedef int (OTF_Handler_Leave) ( void* userData,
@@ -300,7 +313,7 @@ typedef int (OTF_Handler_Leave) ( void* userData,
                                   uint32_t function,
                                   uint32_t process,
                                   uint32_t source,
-				                  OTF_KeyValueList *list );
+                                  OTF_KeyValueList *list );
 
 /* # OTF_SEND_RECORD */
 typedef int (OTF_Handler_SendMsg) ( void* userData,
@@ -311,7 +324,7 @@ typedef int (OTF_Handler_SendMsg) ( void* userData,
                                     uint32_t type,
                                     uint32_t length,
                                     uint32_t source,
-				                    OTF_KeyValueList *list );
+                                    OTF_KeyValueList *list );
 
 /* # OTF_RECEIVE_RECORD */
 typedef int (OTF_Handler_RecvMsg) ( void* userData,
@@ -322,7 +335,7 @@ typedef int (OTF_Handler_RecvMsg) ( void* userData,
                                     uint32_t type,
                                     uint32_t length,
                                     uint32_t source,
-				                    OTF_KeyValueList *list );
+                                    OTF_KeyValueList *list );
 
 /* # OTF_COUNTER_RECORD */
 typedef int (OTF_Handler_Counter) ( void* userData,
@@ -330,7 +343,7 @@ typedef int (OTF_Handler_Counter) ( void* userData,
                                     uint32_t process,
                                     uint32_t counter,
                                     uint64_t value,
-				                    OTF_KeyValueList *list );
+                                    OTF_KeyValueList *list );
 
 /* # OTF_COLLOP_RECORD */
 typedef int (OTF_Handler_CollectiveOperation) ( void* userData,
@@ -343,7 +356,7 @@ typedef int (OTF_Handler_CollectiveOperation) ( void* userData,
                                                 uint32_t received,
                                                 uint64_t duration,
                                                 uint32_t source,
-				  		                        OTF_KeyValueList *list );
+                                                OTF_KeyValueList *list );
 
 /* # OTF_BEGINCOLLOP_RECORD */
 typedef int (OTF_Handler_BeginCollectiveOperation) ( void* userData,
@@ -356,33 +369,33 @@ typedef int (OTF_Handler_BeginCollectiveOperation) ( void* userData,
                                                      uint64_t sent,
                                                      uint64_t received,
                                                      uint32_t scltoken,
-				  		                             OTF_KeyValueList *list );
+                                                     OTF_KeyValueList *list );
 
 /* # OTF_ENDCOLLOP_RECORD */
 typedef int (OTF_Handler_EndCollectiveOperation) ( void* userData,
                                                    uint64_t time,
                                                    uint32_t process,
                                                    uint64_t matchingId,
-				  		                           OTF_KeyValueList *list );
+                                                   OTF_KeyValueList *list );
 
 /* # OTF_EVENTCOMMENT_RECORD */
 typedef int (OTF_Handler_EventComment) ( void* userData,
                                          uint64_t time,
                                          uint32_t process,
                                          const char* comment,
-				  	                     OTF_KeyValueList *list );
+                                         OTF_KeyValueList *list );
 
 /* # OTF_BEGINPROCESS_RECORD */
 typedef int (OTF_Handler_BeginProcess) ( void* userData,
                                          uint64_t time,
                                          uint32_t process,
-				  	                     OTF_KeyValueList *list );
+                                         OTF_KeyValueList *list );
 
 /* # OTF_ENDPROCESS_RECORD */
 typedef int (OTF_Handler_EndProcess) ( void* userData,
                                        uint64_t time,
                                        uint32_t process,
-				                       OTF_KeyValueList *list );
+                                       OTF_KeyValueList *list );
 
 
 /* # OTF_FILEOPERATION_RECORD */
@@ -395,7 +408,7 @@ typedef int (OTF_Handler_FileOperation) ( void* userData,
                                           uint64_t bytes,
                                           uint64_t duration,
                                           uint32_t source,
-				  	                      OTF_KeyValueList *list );
+                                          OTF_KeyValueList *list );
 
 /* # OTF_BEGINFILEOP_RECORD */
 typedef int (OTF_Handler_BeginFileOperation) ( void* userData,
@@ -403,7 +416,7 @@ typedef int (OTF_Handler_BeginFileOperation) ( void* userData,
                                                uint32_t process,
                                                uint64_t matchingId,
                                                uint32_t scltoken,
-				  	                           OTF_KeyValueList *list );
+                                               OTF_KeyValueList *list );
 
 /* # OTF_ENDFILEOP_RECORD */
 typedef int (OTF_Handler_EndFileOperation) ( void* userData,
@@ -415,7 +428,7 @@ typedef int (OTF_Handler_EndFileOperation) ( void* userData,
                                              uint32_t operation,
                                              uint64_t bytes,
                                              uint32_t scltoken,
-				  	                         OTF_KeyValueList *list );
+                                             OTF_KeyValueList *list );
 
 /* # OTF_RMAPUT_RECORD */
 typedef int (OTF_Handler_RMAPut) ( void* userData,
@@ -427,7 +440,7 @@ typedef int (OTF_Handler_RMAPut) ( void* userData,
                                    uint32_t tag,
                                    uint64_t bytes,
                                    uint32_t source,
-				                   OTF_KeyValueList *list );
+                                   OTF_KeyValueList *list );
 
 /* # OTF_RMAPUTRE_RECORD */
 typedef int (OTF_Handler_RMAPutRemoteEnd) ( void* userData,
@@ -439,7 +452,7 @@ typedef int (OTF_Handler_RMAPutRemoteEnd) ( void* userData,
                                             uint32_t tag,
                                             uint64_t bytes,
                                             uint32_t source,
-				  	                        OTF_KeyValueList *list );
+                                            OTF_KeyValueList *list );
 
 /* # OTF_RMAGET_RECORD */
 typedef int (OTF_Handler_RMAGet) ( void* userData,
@@ -451,7 +464,7 @@ typedef int (OTF_Handler_RMAGet) ( void* userData,
                                    uint32_t tag,
                                    uint64_t bytes,
                                    uint32_t source,
-				                   OTF_KeyValueList *list );
+                                   OTF_KeyValueList *list );
 
 /* # OTF_RMAEND_RECORD */
 typedef int (OTF_Handler_RMAEnd) ( void* userData,
@@ -461,8 +474,7 @@ typedef int (OTF_Handler_RMAEnd) ( void* userData,
                                    uint32_t communicator,
                                    uint32_t tag,
                                    uint32_t source,
-				                   OTF_KeyValueList *list );
-
+                                   OTF_KeyValueList *list );
 
 /* typedefs for OTF snapshot records *************************************** */
 
@@ -472,7 +484,7 @@ typedef int (OTF_Handler_SnapshotComment) ( void* userData,
                                             uint64_t time,
                                             uint32_t process,
                                             const char* comment,
-				  	                        OTF_KeyValueList *list );
+                                            OTF_KeyValueList *list );
 
 /* # OTF_ENTERSNAPSHOT_RECORD */
 typedef int (OTF_Handler_EnterSnapshot) ( void *userData,
@@ -481,19 +493,19 @@ typedef int (OTF_Handler_EnterSnapshot) ( void *userData,
                                           uint32_t function,
                                           uint32_t process,
                                           uint32_t source,
-				  	                      OTF_KeyValueList *list );
+                                          OTF_KeyValueList *list );
 
 /* # OTF_SENDSNAPSHOT_RECORD */
 typedef int (OTF_Handler_SendSnapshot) ( void *userData,
-                                            uint64_t time,
-                                            uint64_t originaltime,
-                                            uint32_t sender,
-                                            uint32_t receiver,
-                                            uint32_t procGroup,
-                                            uint32_t tag,
-                                            uint32_t length,
-                                            uint32_t source,
-				  	                        OTF_KeyValueList *list );
+                                         uint64_t time,
+                                         uint64_t originaltime,
+                                         uint32_t sender,
+                                         uint32_t receiver,
+                                         uint32_t procGroup,
+                                         uint32_t tag,
+                                         uint32_t length,
+                                         uint32_t source,
+                                         OTF_KeyValueList *list );
 
 /* # OTF_OPENFILESNAPSHOT_RECORD */
 typedef int (OTF_Handler_OpenFileSnapshot) ( void* userData,
@@ -503,7 +515,7 @@ typedef int (OTF_Handler_OpenFileSnapshot) ( void* userData,
                                              uint32_t process,
                                              uint64_t handleid,
                                              uint32_t source,
-				  	                         OTF_KeyValueList *list );
+                                             OTF_KeyValueList *list );
 
 /* # OTF_BEGINCOLLOPSNAPSHOT_RECORD */
 typedef int (OTF_Handler_BeginCollopSnapshot) ( void* userData,
@@ -517,16 +529,33 @@ typedef int (OTF_Handler_BeginCollopSnapshot) ( void* userData,
                                                 uint64_t sent,
                                                 uint64_t received,
                                                 uint32_t scltoken,
-				  		                        OTF_KeyValueList *list );
+                                                OTF_KeyValueList *list );
 
 /* # OTF_BEGINFILEOPSNAPSHOT_RECORD */
 typedef int (OTF_Handler_BeginFileOpSnapshot) ( void* userData,
-                                               uint64_t time,
-                                               uint64_t originaltime,
-                                               uint32_t process,
-                                               uint64_t matchingId,
-                                               uint32_t scltoken,
-				  	                           OTF_KeyValueList *list );
+                                                uint64_t time,
+                                                uint64_t originaltime,
+                                                uint32_t process,
+                                                uint64_t matchingId,
+                                                uint32_t scltoken,
+                                                OTF_KeyValueList *list );
+
+/* # OTF_COLLOPCOUNTSNAPSHOT_RECORD */
+typedef int (OTF_Handler_CollopCountSnapshot) ( void* userData,
+                                                uint64_t time,
+                                                uint32_t process,
+                                                uint32_t communicator,
+                                                uint64_t count,
+                                                OTF_KeyValueList *list );
+
+/* # OTF_COUNTERSNAPSHOT_RECORD */
+typedef int (OTF_Handler_CounterSnapshot) ( void* userData,
+                                            uint64_t time,
+                                            uint64_t originaltime,
+                                            uint32_t process,
+                                            uint32_t counter,
+                                            uint64_t value,
+                                            OTF_KeyValueList *list );
 
 
 /* typedefs for OTF summary records **************************************** */
@@ -537,7 +566,7 @@ typedef int (OTF_Handler_SummaryComment) ( void* userData,
                                            uint64_t time,
                                            uint32_t process,
                                            const char* comment,
-				  	                       OTF_KeyValueList *list );
+                                           OTF_KeyValueList *list );
 
 /* # OTF_FUNCTIONSUMMARY_RECORD */
 typedef int (OTF_Handler_FunctionSummary) ( void* userData,
@@ -547,7 +576,7 @@ typedef int (OTF_Handler_FunctionSummary) ( void* userData,
                                             uint64_t invocations,
                                             uint64_t exclTime,
                                             uint64_t inclTime,
-				  	                        OTF_KeyValueList *list );
+                                            OTF_KeyValueList *list );
 
 /* # OTF_FUNCTIONGROUPSUMMARY_RECORD */
 typedef int (OTF_Handler_FunctionGroupSummary) ( void* userData,
@@ -557,7 +586,7 @@ typedef int (OTF_Handler_FunctionGroupSummary) ( void* userData,
                                                  uint64_t invocations,
                                                  uint64_t exclTime,
                                                  uint64_t inclTime,
-				  	                             OTF_KeyValueList *list );
+                                                 OTF_KeyValueList *list );
 
 /* # OTF_MESSAGESUMMARY_RECORD */
 typedef int (OTF_Handler_MessageSummary) ( void* userData,
@@ -570,7 +599,7 @@ typedef int (OTF_Handler_MessageSummary) ( void* userData,
                                            uint64_t receivedNumber,
                                            uint64_t sentBytes,
                                            uint64_t receivedBytes,
-				  	                       OTF_KeyValueList *list );
+                                           OTF_KeyValueList *list );
 
 /* # OTF_COLLOPSUMMARY_RECORD */
 typedef int (OTF_Handler_CollopSummary) ( void *userData,
@@ -582,7 +611,7 @@ typedef int (OTF_Handler_CollopSummary) ( void *userData,
                                           uint64_t receivedNumber,
                                           uint64_t sentBytes,
                                           uint64_t receivedBytes,
-				  	                      OTF_KeyValueList *list );
+                                          OTF_KeyValueList *list );
 
 /* # OTF_FILEOPERATIONSUMMARY_RECORD */
 typedef int (OTF_Handler_FileOperationSummary) ( void* userData,
@@ -596,7 +625,7 @@ typedef int (OTF_Handler_FileOperationSummary) ( void* userData,
                                                  uint64_t nseek,
                                                  uint64_t bytesread,
                                                  uint64_t byteswrite,
-				  		                         OTF_KeyValueList *list );
+                                                 OTF_KeyValueList *list );
 
 /* # OTF_FILEGROUPOPERATIONSUMMARY_RECORD */
 typedef int (OTF_Handler_FileGroupOperationSummary) ( void* userData,
@@ -610,7 +639,7 @@ typedef int (OTF_Handler_FileGroupOperationSummary) ( void* userData,
                                                       uint64_t nseek,
                                                       uint64_t bytesread,
                                                       uint64_t byteswrite,
-				  	 	                              OTF_KeyValueList *list );
+                                                      OTF_KeyValueList *list );
 
 /* # OTF_UNKNOWN_RECORD */
 typedef int (OTF_Handler_UnknownRecord) ( void *userData,
@@ -628,7 +657,7 @@ typedef int (OTF_Handler_DefMarker) ( void *userData,
                                       uint32_t token,
                                       const char* name,
                                       uint32_t type,
-				                      OTF_KeyValueList *list );
+                                      OTF_KeyValueList *list );
 
 /* # OTF_MARKER_RECORD */
 typedef int (OTF_Handler_Marker) ( void *userData,
@@ -636,7 +665,7 @@ typedef int (OTF_Handler_Marker) ( void *userData,
                                    uint32_t process,
                                    uint32_t token,
                                    const char* text,
-				                   OTF_KeyValueList *list );
+                                   OTF_KeyValueList *list );
 
 /** @endcond */
 
@@ -645,4 +674,3 @@ typedef int (OTF_Handler_Marker) ( void *userData,
 #endif /* __cplusplus */
 
 #endif /* OTF_HANDLERARRAY_H */
-
