@@ -1,5 +1,5 @@
 /*
- This is part of the OTF library. Copyright by ZIH, TU Dresden 2005-2011.
+ This is part of the OTF library. Copyright by ZIH, TU Dresden 2005-2012.
  Authors: Andreas Knuepfer, Holger Brunst, Ronny Brendel, Thomas Kriebitzsch, Johannes Spazier
 */
 
@@ -231,9 +231,9 @@ struct OTF_KeyValueList_struct {
 	uint32_t key_count;             /* number of different keys in list --> user-relevant */
 	uint32_t count;                 /* total number of entries in list (treat byte arrays particular) --> internal use only */
 	uint32_t size;                  /* number of allocated entries --> internal */
-	OTF_KeyValuePairList *kvBegin;
-	OTF_KeyValuePairList *kvEnd;
-	OTF_KeyValuePairList *kvCurrent;
+	OTF_KeyValuePairList *kvBegin;   /* first element of the list */
+	OTF_KeyValuePairList *kvEnd;     /* last allocated element of the list, may be used or not */
+	OTF_KeyValuePairList *kvCurrent; /* first unused element in the list, insert new ones here */
 };
 
 /** @endcond */
@@ -268,6 +268,19 @@ OTF_KeyValueList *OTF_KeyValueList_new(void);
 uint8_t OTF_KeyValueList_close(OTF_KeyValueList* list);
 
 
+/**
+ * Clone an OTF_KeyValueList instance.
+ *
+ * @param list     Pointer to an initialized OTF_KeyValueList object or NULL.
+ *                 See also OTF_KeyValueList_new().
+ * 
+ * @return	   Clone of the instance @a list or NULL.
+ *
+ * \ingroup keyvalue
+ */
+OTF_KeyValueList* OTF_KeyValueList_clone(OTF_KeyValueList* list);
+
+
 /** 
  * Reset an OTF_KeyValueList instance without deallocating memory.
  *
