@@ -13,7 +13,9 @@
 
 #include "vt_dyn.h"
 
+#include "BPatch_flowGraph.h"
 #include "BPatch_module.h"
+#include "BPatch_point.h"
 #include "BPatch_process.h"
 #include "BPatch_snippet.h"
 #include "BPatch_statement.h"
@@ -444,17 +446,18 @@ MutatorC::initialize()
 
       // examples:
 
-      //RFG_Filter_add( m_filter, "foo", 0, 0, 0 );
-      //RFG_Filter_add( m_filter, "bar", 0, 0, 0 );
+      //RFG_Filter_addRegionRules( m_filter, "foo", 0, 0, 0 );
+      //RFG_Filter_addRegionRules( m_filter, "bar", 0, 0, 0 );
 
       // instrumenting this function generated by the Intel compiler
       // causes a segmentation fault at application runtime
-      RFG_Filter_add( m_filter, "__intel_cpu_indicator_init", 0, 0, 0 );
+      RFG_Filter_addRegionRules( m_filter, "__intel_cpu_indicator_init",
+        0, 0, 0 );
 
       // this function, also a built-in function from the Intel compiler,
       // causes aborting instrumentation
       // (reported by David Shrader / LANL)
-      RFG_Filter_add( m_filter, "__intel_proc_init_N", 0, 0, 0 );
+      RFG_Filter_addRegionRules( m_filter, "__intel_proc_init_N", 0, 0, 0 );
 
       // create/attach to a process or open binary for rewriting
       //
@@ -595,8 +598,8 @@ MutatorC::initialize()
       // search instrumentation functions to insert at entry/exit points
       //
 
-      if( !findFunction( "VT_Dyn_start", m_vtStartFunc ) ||
-          !findFunction( "VT_Dyn_end", m_vtEndFunc ) )
+      if( !findFunction( "vt_dyn_start", m_vtStartFunc ) ||
+          !findFunction( "vt_dyn_end", m_vtEndFunc ) )
       {
          std::cerr << ExeName << ": [" << ExePid << "]: "
                    << "Error: Could not find instrumentation functions. "
@@ -639,9 +642,9 @@ MutatorC::finalize( bool & error )
                // send mutatee process a signal to continue execution
                //
                if( Params.mutatee_pid != -1 )
-                  kill( Params.mutatee_pid, SIGUSR1 );
+                  kill( Params.mutatee_pid, VT_DYNINST_CONT_SIGNUM );
 
-               if( Params.mode == MODE_CREATE || !Params.detach )
+               if( !Params.detach )
                {
                   // continue execution of mutatee
                   app_process->continueExecution();
@@ -657,7 +660,7 @@ MutatorC::finalize( bool & error )
                   vPrint( 1, "End of process\n" );
                   vPrint( 1, "Done\n" );
                }
-               else // Params.mode == MODE_ATTACH && Params.detach
+               else
                {
                   // continue execution of mutatee and detach from its process
                   app_process->detach( true );
@@ -1369,7 +1372,7 @@ MutatorC::constraintRegion( const std::string & name ) const
    {
       int32_t limit;
       uint8_t flags;
-      RFG_Filter_get( m_filter, name.c_str(), 0, &limit, 0, &flags );
+      RFG_Filter_getRegionRules( m_filter, name.c_str(), 0, &limit, 0, &flags );
 
       // don't instrument function if call limit is 0 and function isn't
       // filtered recursively
