@@ -10,7 +10,6 @@
  * See the file COPYING in the package base directory for details
  **/
 
-#include "vt_unify.h"
 #include "vt_unify_defs.h"
 #include "vt_unify_handlers.h"
 #include "vt_unify_hooks.h"
@@ -19,10 +18,22 @@
 #include "vt_unify_tkfac.h"
 #include "vt_unify_usrcom.h"
 
-#include "otf.h"
+#ifdef VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
 
-void
-HandleKeyValueList( const uint32_t & proc, OTF_KeyValueList * kvs )
+// check whether given stream id is available
+static bool
+isStreamAvail( const uint32_t streamid )
+{
+   return
+      ( AbsentStreamIds.empty() ||
+        AbsentStreamIds.find( streamid ) == AbsentStreamIds.end() );
+}
+
+#endif // VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+
+// translate local key tokens to global tokens
+static void
+handleKeyValueList( const uint32_t & proc, OTF_KeyValueList * kvs )
 {
    // get number of key-value pairs
    uint32_t keys_num = OTF_KeyValueList_getCount( kvs );
@@ -50,6 +61,15 @@ HandleKeyValueList( const uint32_t & proc, OTF_KeyValueList * kvs )
    }
 }
 
+// key-value list "record handler"
+void
+HandleKeyValueList( const uint32_t & proc, OTF_KeyValueList * kvs )
+{
+   // call the local version of this function which should hopefully
+   // be inlined
+   handleKeyValueList( proc, kvs );
+}
+
 // definition record handlers
 //
 
@@ -283,6 +303,27 @@ HandleDefProcessGroup( FirstHandlerArg_DefsS * fha,
       type = DefRec_DefProcessGroupS::TYPE_OTHER;
    }
 
+#ifdef VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+   if( n > 0 && !AbsentStreamIds.empty() &&
+       type != DefRec_DefProcessGroupS::TYPE_ALL &&
+       type != DefRec_DefProcessGroupS::TYPE_NODE &&
+       type != DefRec_DefProcessGroupS::TYPE_MPI_COMM_SELF )
+   {
+      // remove unavailable stream ids from member array
+      //
+      uint32_t j = 0;
+      for( uint32_t i = 0; i < n; i++ )
+      {
+         if( isStreamAvail( array[i] ) && j < i )
+            array[j++] = array[i];
+      }
+      n = j;
+      // drop record, if member array is empty
+      if( n == 0 )
+         return OTF_RETURN_OK;
+   }
+#endif // VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+
    // add local definition to vector
    fha->loc_defs.push_back( new DefRec_DefProcessGroupS
                                ( streamid, deftoken, type, _name, n,
@@ -556,7 +597,7 @@ HandleEventComment( FirstHandlerArg_EventsS * fha,
       &time, &proc, &_comment, &kvs );
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
 #ifdef VT_ETIMESYNC
    // update time sync. parameters, if necessary
@@ -629,7 +670,7 @@ HandleEnter( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
@@ -688,7 +729,7 @@ HandleLeave( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
@@ -747,7 +788,7 @@ HandleCounter( FirstHandlerArg_EventsS * fha,
    assert( global_counter != 0 );
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
@@ -794,7 +835,7 @@ HandleBeginFileOp( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
@@ -849,7 +890,7 @@ HandleEndFileOp( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
@@ -905,7 +946,7 @@ HandleSendMsg( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( sender, kvs );
+   handleKeyValueList( sender, kvs );
 
    // correct time
    time = theTimeSync->correctTime( sender, time );
@@ -919,6 +960,12 @@ HandleSendMsg( FirstHandlerArg_EventsS * fha,
       return OTF_RETURN_OK;
    }
 
+#ifdef VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+   // drop record, if receiver stream isn't available
+   if( !isStreamAvail( receiver ) )
+      return OTF_RETURN_OK;
+#endif // VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+
    // trigger write record hook
    theHooks->triggerWriteRecordHook( HooksC::Record_SendMsg, 10,
       &(fha->wstream), &time, &sender, &receiver, &global_comm, &tag, &length,
@@ -969,7 +1016,7 @@ HandleRecvMsg( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( receiver, kvs );
+   handleKeyValueList( receiver, kvs );
 
    // correct time
    time = theTimeSync->correctTime( receiver, time );
@@ -983,6 +1030,12 @@ HandleRecvMsg( FirstHandlerArg_EventsS * fha,
       return OTF_RETURN_OK;
    }
 
+#ifdef VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+   // drop record, if sender stream isn't available
+   if( !isStreamAvail( sender ) )
+      return OTF_RETURN_OK;
+#endif // VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+
    // trigger write record hook
    theHooks->triggerWriteRecordHook( HooksC::Record_RecvMsg, 10,
       &(fha->wstream), &time, &receiver, &sender, &global_comm, &tag, &length,
@@ -1044,7 +1097,7 @@ HandleBeginCollOp( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
@@ -1077,7 +1130,7 @@ HandleEndCollOp( FirstHandlerArg_EventsS * fha,
       &time, &proc, &matchid, &kvs );
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
@@ -1116,6 +1169,12 @@ HandleRMAPut( FirstHandlerArg_EventsS * fha,
    static const TokenFactoryScopeI * tkfac_defscl =
       theTokenFactory->getScope( DEF_REC_TYPE__DefScl );
 
+#ifdef VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+   // drop record, if origin or destination stream isn't available
+   if( !isStreamAvail( origin ) || !isStreamAvail( dest ) )
+      return OTF_RETURN_OK;
+#endif // VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+
    // translate local comm. token
    //
    uint32_t global_comm = tkfac_defprocgrp->translate( proc, comm );
@@ -1131,7 +1190,7 @@ HandleRMAPut( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
@@ -1171,6 +1230,12 @@ HandleRMAPutRemoteEnd( FirstHandlerArg_EventsS * fha,
    static const TokenFactoryScopeI * tkfac_defscl =
       theTokenFactory->getScope( DEF_REC_TYPE__DefScl );
 
+#ifdef VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+   // drop record, if origin or destination stream isn't available
+   if( !isStreamAvail( origin ) || !isStreamAvail( dest ) )
+      return OTF_RETURN_OK;
+#endif // VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+
    // translate local comm. token
    //
    uint32_t global_comm = tkfac_defprocgrp->translate( proc, comm );
@@ -1186,7 +1251,7 @@ HandleRMAPutRemoteEnd( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
@@ -1226,6 +1291,12 @@ HandleRMAGet( FirstHandlerArg_EventsS * fha,
    static const TokenFactoryScopeI * tkfac_defscl =
       theTokenFactory->getScope( DEF_REC_TYPE__DefScl );
 
+#ifdef VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+   // drop record, if origin or destination stream isn't available
+   if( !isStreamAvail( origin ) || !isStreamAvail( dest ) )
+      return OTF_RETURN_OK;
+#endif // VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+
    // translate local comm. token
    //
    uint32_t global_comm = tkfac_defprocgrp->translate( proc, comm );
@@ -1241,7 +1312,7 @@ HandleRMAGet( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
@@ -1281,6 +1352,12 @@ HandleRMAEnd( FirstHandlerArg_EventsS * fha,
    static const TokenFactoryScopeI * tkfac_defscl =
       theTokenFactory->getScope( DEF_REC_TYPE__DefScl );
 
+#ifdef VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+   // drop record, if remote stream isn't available
+   if( !isStreamAvail( remote ) )
+      return OTF_RETURN_OK;
+#endif // VT_UNIFY_REMOVE_UNDEF_PROCID_REFERENCES
+
    // translate local comm. token
    //
    uint32_t global_comm = tkfac_defprocgrp->translate( proc, comm );
@@ -1296,7 +1373,7 @@ HandleRMAEnd( FirstHandlerArg_EventsS * fha,
    }
 
    // translate local key token(s)
-   HandleKeyValueList( proc, kvs );
+   handleKeyValueList( proc, kvs );
 
    // correct time
    time = theTimeSync->correctTime( proc, time );
