@@ -37,7 +37,7 @@ typedef unsigned char* buffer_t;
  */
 
 #define VT_PROCESS_ID_BITNESS    32
-#define VT_PROCESS_ID_SPLITTING  16
+#define VT_PROCESS_ID_SPLITTING  20
 #define VT_TRACEID_BITMASK       ((1<<VT_PROCESS_ID_SPLITTING) - 1)
 #define VT_THREADID_BITMASK      (~VT_TRACEID_BITMASK)
 #define VT_PROCESS_ID(trace_id, thread_id) \
@@ -146,11 +146,6 @@ typedef unsigned char* buffer_t;
 #define VT_LOOP                  3
 #define VT_USER_REGION           4
 
-#define VT_LIBC                  5
-#define VT_LIBC_IO               6
-
-#define VT_MEMORY                7
-
 #define VT_MPI_FUNCTION          8
 #define VT_MPI_COLL_BARRIER      9
 #define VT_MPI_COLL_ONE2ALL     10
@@ -276,6 +271,15 @@ typedef unsigned char* buffer_t;
 #define VT_KEYVAL_TYPE_UINT64  4
 #define VT_KEYVAL_TYPE_FLOAT   5
 #define VT_KEYVAL_TYPE_DOUBLE  6
+#define VT_KEYVAL_TYPE_STRING  7
+
+/*
+ *-----------------------------------------------------------------------------
+ * VT libraries/vtunify compatibility identifier
+ *-----------------------------------------------------------------------------
+ */
+
+#define VT_UNIFY_COMPAT_ID  1000
 
 /*
  *-----------------------------------------------------------------------------
@@ -300,6 +304,17 @@ typedef unsigned char* buffer_t;
 
 #define VT_UNIFY_STRID_ASYNC_SOURCE_KEY         "__ASYNC_SOURCE__"
 
+/*
+ *-----------------------------------------------------------------------------
+ * IOFSL modes and flags
+ *-----------------------------------------------------------------------------
+ */
+
+#define VT_IOFSL_MODE_MULTIFILE        0
+#define VT_IOFSL_MODE_MULTIFILE_SPLIT  1
+
+#define VT_IOFSL_FLAG_ASYNC_IO         1<<0
+
 /*
  *-----------------------------------------------------------------------------
  * Miscellaneous
@@ -308,4 +323,7 @@ typedef unsigned char* buffer_t;
 
 #define VT_MAX_GETHOSTID_RETRIES  10
 
+#define VT_DYNINST_CONT_SIGNUM    SIGUSR1
+#define VT_DYNINST_ERROR_SIGNUM   SIGUSR2
+
 #endif /* _VT_DEFS_H */
