@@ -2,7 +2,7 @@
  * VampirTrace
  * http://www.tu-dresden.de/zih/vampirtrace
  *
- * Copyright (c) 2005-2011, ZIH, TU Dresden, Federal Republic of Germany
+ * Copyright (c) 2005-2012, ZIH, TU Dresden, Federal Republic of Germany
  *
  * Copyright (c) 1998-2005, Forschungszentrum Juelich, Juelich Supercomputing
  *                          Centre, Federal Republic of Germany
@@ -41,9 +41,6 @@ EXTERN void vt_warning(const char* fmt, ...);
 /* user control message without abort (printed only if VT_VERBOSE is set) */
 EXTERN void vt_cntl_msg(int level, const char* fmt, ...);
 
-/* debug messages without abort (printed only if VT_DEBUG is set) */
-EXTERN void vt_debug_msg(int level, const char* fmt, ...);
-
 #endif
 
 
