@@ -101,27 +101,36 @@ int ompi_mtl_mxm_send(struct mca_mtl_base_module_t* mtl,
     mxm_send_req.base.state         = MXM_REQ_NEW;
     mxm_send_req.base.mq            = ompi_mtl_mxm_mq_lookup(comm);
     mxm_send_req.base.conn          = ompi_mtl_mxm_conn_lookup(comm, dest);
-    mxm_send_req.base.flags         = MXM_REQ_FLAG_BLOCKING;
-
     mxm_send_req.base.context       = NULL;
+    mxm_send_req.base.completed_cb  = NULL;
+
     ret = ompi_mtl_mxm_choose_send_datatype(&mxm_send_req, convertor);
     if (OPAL_UNLIKELY(OMPI_SUCCESS != ret)) {
         return ret;
     }
+
 #if MXM_API < MXM_VERSION(1,5)
     mxm_send_req.base.data.buffer.mkey   = MXM_MKEY_NONE;
 #else
     mxm_send_req.base.data.buffer.memh   = MXM_INVALID_MEM_HANDLE;
 #endif
-    mxm_send_req.base.completed_cb       = NULL;
+
+    mxm_send_req.op.send.tag             = tag;
+    mxm_send_req.op.send.imm_data        = ompi_comm_rank(comm);
+#if MXM_API < MXM_VERSION(2,0)
+    mxm_send_req.base.flags              = MXM_REQ_FLAG_BLOCKING;
+    mxm_send_req.opcode                  = MXM_REQ_OP_SEND;
     if (mode == MCA_PML_BASE_SEND_SYNCHRONOUS) {
         mxm_send_req.base.flags          |= MXM_REQ_FLAG_SEND_SYNC;
     }
-
-    mxm_send_req.opcode                  = MXM_REQ_OP_SEND;
-    mxm_send_req.op.send.tag             = tag;
-    mxm_send_req.op.send.imm_data        = ompi_comm_rank(comm);
-
+#else
+    mxm_send_req.flags                   = MXM_REQ_SEND_FLAG_BLOCKING;
+    if (mode == MCA_PML_BASE_SEND_SYNCHRONOUS) {
+        mxm_send_req.opcode              = MXM_REQ_OP_SEND_SYNC;
+    } else {
+        mxm_send_req.opcode              = MXM_REQ_OP_SEND;
+    }
+#endif
 
     /* post-send */
     err = mxm_req_send(&mxm_send_req);
@@ -163,12 +172,14 @@ int ompi_mtl_mxm_isend(struct mca_mtl_base_module_t* mtl,
     }
 
     mxm_send_req = &mtl_mxm_request->mxm.send;
+#if MXM_API >= MXM_VERSION(2,0)
+    mtl_mxm_request->is_send = 1;
+#endif
 
     /* prepare a send request embedded in the MTL request */
     mxm_send_req->base.state               = MXM_REQ_NEW;
     mxm_send_req->base.mq                  = ompi_mtl_mxm_mq_lookup(comm);
     mxm_send_req->base.conn                = ompi_mtl_mxm_conn_lookup(comm, dest);
-    mxm_send_req->base.flags               = 0;
     mxm_send_req->base.data_type           = MXM_REQ_DATA_BUFFER;
     mxm_send_req->base.data.buffer.ptr     = mtl_mxm_request->buf;
     mxm_send_req->base.data.buffer.length  = mtl_mxm_request->length;
@@ -179,11 +190,22 @@ int ompi_mtl_mxm_isend(struct mca_mtl_base_module_t* mtl,
 #endif
     mxm_send_req->base.context             = mtl_mxm_request;
     mxm_send_req->base.completed_cb        = ompi_mtl_mxm_send_completion_cb;
+
+#if MXM_API < MXM_VERSION(2,0)
+    mxm_send_req->base.flags               = 0;
+    mxm_send_req->opcode                   = MXM_REQ_OP_SEND;
     if (mode == MCA_PML_BASE_SEND_SYNCHRONOUS) {
         mxm_send_req->base.flags           |= MXM_REQ_FLAG_SEND_SYNC;
+    } else {
     }
-
-    mxm_send_req->opcode                   = MXM_REQ_OP_SEND;
+#else
+    mxm_send_req->flags                    = 0;
+    if (mode == MCA_PML_BASE_SEND_SYNCHRONOUS) {
+        mxm_send_req->opcode               = MXM_REQ_OP_SEND_SYNC;
+    } else {
+        mxm_send_req->opcode               = MXM_REQ_OP_SEND;
+    }
+#endif
     mxm_send_req->op.send.tag              = tag;
     mxm_send_req->op.send.imm_data         = ompi_comm_rank(comm);
 
