@@ -20,13 +20,15 @@
 #include "ompi_config.h"
 #include <stdio.h>
 
-#include "orte/util/show_help.h"
 #include "ompi/mpi/c/bindings.h"
+#include "ompi/runtime/params.h"
+#include "ompi/communicator/communicator.h"
+#include "ompi/errhandler/errhandler.h"
 #include "ompi/info/info.h"
 #include "ompi/mca/dpm/dpm.h"
 #include "ompi/memchecker.h"
 
-#if OMPI_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
 #pragma weak MPI_Comm_spawn_multiple = PMPI_Comm_spawn_multiple
 #endif
 
@@ -42,7 +44,7 @@ int MPI_Comm_spawn_multiple(int count, char **array_of_commands, char ***array_o
                             int root, MPI_Comm comm, MPI_Comm *intercomm,
                             int *array_of_errcodes) 
 {
-    int i=0, rc=0, rank=0, flag;
+    int i=0, rc=0, rank=0, size=0, flag;
     ompi_communicator_t *newcomp=NULL;
     bool send_first=false; /* they are contacting us first */
     char port_name[MPI_MAX_PORT_NAME];
@@ -148,9 +150,9 @@ int MPI_Comm_spawn_multiple(int count, char **array_of_commands, char ***array_o
                 goto error;
             }
         } else if (1 < ompi_comm_size(comm)) {
-             /* we do not support non_mpi spawns on comms this size */
-             rc = OMPI_ERR_NOT_SUPPORTED;
-             goto error;
+            /* we do not support non_mpi spawns on comms this size */
+            rc = OMPI_ERR_NOT_SUPPORTED;
+            goto error;
         }
         if (OMPI_SUCCESS != (rc = ompi_dpm.spawn(count, array_of_commands,
                                                  array_of_argv, array_of_maxprocs,
@@ -175,8 +177,18 @@ error:
     
     /* set array of errorcodes */
     if (MPI_ERRCODES_IGNORE != array_of_errcodes) {
-        for ( i=0; i < newcomp->c_remote_group->grp_proc_count; i++ ) {
-            array_of_errcodes[i]=rc;
+        if (NULL != newcomp) {
+            for ( i=0; i < newcomp->c_remote_group->grp_proc_count; i++ ) {
+                array_of_errcodes[i]=rc;
+            }
+        } else {
+            for ( i=0; i < count; i++) {
+                size = size + array_of_maxprocs[i];
+            }
+
+            for ( i=0; i < size; i++) {
+                array_of_errcodes[i]=rc;
+            }
         }
     }
 
